@@ -1,11 +1,12 @@
 from dataclasses import dataclass, field
+from datetime import datetime
 from enum import Enum
-from typing import Dict, List, Optional, Set, Union
+from typing import Dict, List, Optional, Set, Type, Union
 
 from dataclasses_jsonschema import JsonSchemaMixin
 
 from arcor2.data import DataException
-from arcor2.data.common import ActionMetadata, Pose, Position
+from arcor2.data.common import Pose
 
 
 class Model3dType(Enum):
@@ -49,6 +50,16 @@ class Box(Model):
     size_y: float
     size_z: float
 
+    def __post_init__(self) -> None:
+
+        dims = [self.size_x, self.size_y, self.size_z]
+
+        if [val for val in dims if val < 0]:
+            raise DataException("Dimensions has to be positive.")
+
+        if len([val for val in dims if val > 0]) < 2:
+            raise DataException("Only one dimension of a box can be zero.")
+
 
 @dataclass
 class Cylinder(Model):
@@ -56,42 +67,61 @@ class Cylinder(Model):
     radius: float
     height: float
 
+    def __post_init__(self) -> None:
+
+        if [val for val in [self.radius, self.height] if val <= 0]:
+            raise DataException("Dimensions has to be positive.")
+
 
 @dataclass
 class Sphere(Model):
     radius: float
 
+    def __post_init__(self) -> None:
+
+        if self.radius <= 0:
+            raise DataException("Radius has to be positive.")
+
 
 @dataclass
 class Mesh(Model):
 
-    uri: str
+    data_id: str
     focus_points: Optional[List[Pose]] = None
 
 
 MeshList = List[Mesh]
 
+PrimitiveModels = Union[Box, Sphere, Cylinder]
 Models = Union[Box, Sphere, Cylinder, Mesh]
 
-MODEL_MAPPING = {Box.type(): Box,
-                 Sphere.type(): Sphere,
-                 Cylinder.type(): Cylinder,
-                 Mesh.type(): Mesh}
+MODEL_MAPPING: Dict[Model3dType, Union[Type[Box], Type[Sphere], Type[Cylinder], Type[Mesh]]] = {
+    Box.type(): Box,
+    Sphere.type(): Sphere,
+    Cylinder.type(): Cylinder,
+    Mesh.type(): Mesh,
+}
 
 
 @dataclass
 class ObjectType(JsonSchemaMixin):
-    """
-    Object type, as it is stored in DB.
-    """
+    """Object type, as it is stored in DB."""
 
     id: str
     source: str
-    desc: Optional[str] = ""
+    name: str = field(init=False)
+
+    description: Optional[str] = None
     model: Optional[MetaModel3d] = None
 
-    def __post_init__(self) -> None:  # TODO workaround for bug (?) in Storage
+    created: Optional[datetime] = None
+    modified: Optional[datetime] = None
 
+    def __post_init__(self) -> None:
+
+        self.name = self.id  # name makes no sense for ObjectType but is required by the Project service
+
+        # TODO workaround for bug (?) in Project service
         if self.model and self.model.type == Model3dType.NONE:
             self.model = None
 
@@ -106,90 +136,18 @@ class ObjectModel(JsonSchemaMixin):
     mesh: Optional[Mesh] = None
 
     def model(self) -> Models:
+
+        assert self.type != Model3dType.NONE
         return getattr(self, str(self.type.value).lower())
 
     def __post_init__(self) -> None:
 
         models_list = [self.box, self.cylinder, self.sphere, self.mesh]
 
-        if models_list.count(None) != len(models_list)-1:
+        if models_list.count(None) != len(models_list) - 1:
             raise DataException("No model specified!")
 
 
-@dataclass
-class ObjectTypeMeta(JsonSchemaMixin):
-    """
-    Metadata about object type, as it is used in server API.
-    """
-
-    type: str
-    description: str = field(default_factory=str)
-    built_in: bool = False
-    base: str = field(default_factory=str)
-    object_model: Optional[ObjectModel] = None
-    needs_services: Set[str] = field(default_factory=set)
-    abstract: bool = False
-    disabled: bool = False
-    problem: Optional[str] = None
-
-    def to_object_type(self) -> ObjectType:
-
-        ot = ObjectType(self.type, "", self.description)
-
-        if self.object_model:
-
-            if self.object_model.type == Model3dType.MESH:
-                assert self.object_model.mesh
-                m_id = self.object_model.mesh.id
-            else:
-                m_id = self.type
-
-            ot.model = MetaModel3d(m_id, self.object_model.type)
-
-        return ot
-
-
-@dataclass
-class ActionParameterMeta(JsonSchemaMixin):
-
-    name: str
-    type: str
-    dynamic_value: bool = False  # client should ask for allowed values using RPC
-    dynamic_value_parents: Optional[Set[str]] = None
-    description: Optional[str] = None
-    default_value: Optional[str] = None
-    extra: Optional[str] = None
-
-
-@dataclass
-class ObjectAction(JsonSchemaMixin):
-
-    name: str
-    description: Optional[str] = None
-    parameters: List[ActionParameterMeta] = field(default_factory=list)
-    meta: ActionMetadata = field(default_factory=ActionMetadata)
-    origins: Optional[str] = None
-    returns: Optional[str] = None
-    disabled: bool = False
-    problem: Optional[str] = None
-
-
-ObjectTypeMetaDict = Dict[str, ObjectTypeMeta]
-ObjectActions = List[ObjectAction]
-ObjectActionsDict = Dict[str, ObjectActions]
-
-
-@dataclass
-class MeshFocusAction(JsonSchemaMixin):
-
-    mesh_focus_points: List[Position]
-    robot_space_points: List[Position]
-
-    def __post_init__(self) -> None:
-
-        assert len(self.mesh_focus_points) == len(self.robot_space_points)
-
-
 @dataclass
 class CollisionModels(JsonSchemaMixin):
 
@@ -197,3 +155,16 @@ class CollisionModels(JsonSchemaMixin):
     spheres: List[Sphere] = field(default_factory=list)
     cylinders: List[Cylinder] = field(default_factory=list)
     meshes: List[Mesh] = field(default_factory=list)
+
+
+@dataclass
+class ParameterMeta(JsonSchemaMixin):
+
+    name: str
+    type: str
+    dynamic_value: bool = False  # client should ask for allowed values using RPC
+    dynamic_value_parents: Optional[Set[str]] = None
+    description: Optional[str] = None
+    default_value: Optional[str] = None
+    extra: Optional[str] = None
+    children: List["ParameterMeta"] = field(default_factory=list)
