@@ -1,12 +1,13 @@
+import ast
+from ast import Num
 from dataclasses import dataclass
 from typing import Any, Callable, List, Tuple, Type
 
 from dataclasses_jsonschema import JsonSchemaMixin
 
-from typed_ast import ast3 as ast
-
-from arcor2.data.common import Project, Scene
-from arcor2.data.object_type import ActionParameterMeta
+from arcor2.cached import CachedProject as CProject
+from arcor2.cached import CachedScene as CScene
+from arcor2.data.object_type import ParameterMeta
 from arcor2.parameter_plugins.base import ParameterPlugin, ParameterPluginException, TypesDict
 from arcor2.parameter_plugins.list import ListParameterPlugin, get_type_name
 from arcor2.source.utils import find_asserts
@@ -28,6 +29,7 @@ def get_assert_minimum_maximum(asserts: List[ast.Assert], param_name: str) -> Tu
     # Assert(test=Compare(left=Num(n=0), ops=[LtE(), LtE()], comparators=[Name(id='speed', ctx=Load()), Num(n=100)]))
 
     for ass in asserts:
+
         if not isinstance(ass.test, ast.Compare):
             continue
 
@@ -54,8 +56,9 @@ def get_assert_minimum_maximum(asserts: List[ast.Assert], param_name: str) -> Tu
     raise AssertNotFound()
 
 
-def get_min_max(cls: Type[ParameterPlugin], param_meta: ActionParameterMeta, action_method: Callable,
-                action_node: ast.FunctionDef) -> None:
+def get_min_max(
+    cls: Type[ParameterPlugin], param_meta: ParameterMeta, action_method: Callable, action_node: ast.FunctionDef
+) -> None:
 
     try:
         minimum, maximum = get_assert_minimum_maximum(find_asserts(action_node), param_meta.name)
@@ -70,9 +73,8 @@ def get_min_max(cls: Type[ParameterPlugin], param_meta: ActionParameterMeta, act
 
 
 class IntegerPlugin(ParameterPlugin):
-
     @classmethod
-    def type(cls):
+    def type(cls) -> Any:
         return int
 
     @classmethod
@@ -80,18 +82,29 @@ class IntegerPlugin(ParameterPlugin):
         return "integer"
 
     @classmethod
-    def meta(cls, param_meta: ActionParameterMeta, action_method: Callable, action_node: ast.FunctionDef) -> None:
+    def meta(cls, param_meta: ParameterMeta, action_method: Callable, action_node: ast.FunctionDef) -> None:
 
         super(IntegerPlugin, cls).meta(param_meta, action_method, action_node)
-        get_min_max(IntegerPlugin, param_meta, action_method, action_node)
+        get_min_max(cls, param_meta, action_method, action_node)
 
     @classmethod
-    def value(cls, type_defs: TypesDict, scene: Scene, project: Project, action_id: str, parameter_id: str) -> int:
-        return cls.type()(super(IntegerPlugin, cls).value(type_defs, scene, project, action_id, parameter_id))
+    def parameter_value(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> int:
+        return super(IntegerPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
+
+    @classmethod
+    def _value_from_json(cls, value: str) -> int:
+        return super(IntegerPlugin, cls)._value_from_json(value)
+
+    @classmethod
+    def parameter_ast(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> Num:
+        return Num(n=cls.parameter_execution_value(type_defs, scene, project, action_id, parameter_id), kind=None)
 
 
 class IntegerListPlugin(ListParameterPlugin):
-
     @classmethod
     def type(cls):
         return List[int]
@@ -101,10 +114,11 @@ class IntegerListPlugin(ListParameterPlugin):
         return get_type_name(IntegerPlugin)
 
     @classmethod
-    def meta(cls, param_meta: ActionParameterMeta, action_method: Callable, action_node: ast.FunctionDef) -> None:
+    def meta(cls, param_meta: ParameterMeta, action_method: Callable, action_node: ast.FunctionDef) -> None:
         super(IntegerListPlugin, cls).meta(param_meta, action_method, action_node)
 
     @classmethod
-    def value(cls, type_defs: TypesDict, scene: Scene, project: Project, action_id: str, parameter_id: str) \
-            -> List[int]:
-        return super(IntegerListPlugin, cls).value(type_defs, scene, project, action_id, parameter_id)
+    def parameter_value(
+        cls, type_defs: TypesDict, scene: CScene, project: CProject, action_id: str, parameter_id: str
+    ) -> List[int]:
+        return super(IntegerListPlugin, cls).parameter_value(type_defs, scene, project, action_id, parameter_id)
